Dataflow analysis utilities for the lowering IR.
This module provides generic analysis frameworks that can be used by various optimization passes and semantic checks.
Structs
- Back
Analysis - Main analysis type that allows traversing the flow backwards.
Traits
- Analyzer
- Analyzer trait to implement for each specific analysis.
Type Aliases
- Statement
Location - Location of a lowering statement inside a block.