Module forward

Module forward 

Forward dataflow analysis runner.

This module provides FwdAnalysis, which traverses the control flow graph in forward (topological) order, computing dataflow information from function entry to exits.

Structs

ForwardDataflowAnalysis
Forward analysis runner.