Module statements_weights

Module statements_weights 

Structs

ApproxCasmInlineWeight
Try to approximate the weight of a lowered function by counting the number of CASM statements it will add to the code.
SimpleInlineWeight
A simple inline weight that gives a weight of 1 to each statement and block end.

Traits

InlineWeight
Trait for calculating the weight of a lowered function, for the purpose of inlining.