VarRemapping

Struct VarRemapping 

pub struct VarRemapping<'db> {
    pub remapping: SmallOrderedMap<VariableId, VarUsage<'db>>,
}
Remapping of lowered variable ids. Useful for convergence of branches.

Fields

remapping: SmallOrderedMap<VariableId, VarUsage<'db>>

Map from new_var to old_var (since new_var cannot appear twice, but old_var can).

Methods from Deref<Target = SmallOrderedMap<VariableId, VarUsage<'db>>>

pub fn eq_unordered(&self, other: &SmallOrderedMap<Key, Value>) -> bool

Checks if the two maps have the same keys and values.

Methods from Deref<Target = VecMap<Key, Value>>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn capacity(&self) -> usize

pub fn clear(&mut self)

pub fn contains_key<Q>(&self, key: &Q) -> bool
where Q: PartialEq<K> + ?Sized,

pub fn get<'l, Q>(&'l self, key: &Q) -> Option<&'l V>
where Q: PartialEq<K> + ?Sized,

pub fn get_mut<'l, Q>(&'l mut self, key: &Q) -> Option<&'l mut V>
where Q: PartialEq<K> + ?Sized,

pub fn insert(&mut self, key: K, value: V) -> Option<V>
where K: PartialEq,

pub fn drain(&mut self) -> Drain<'_, K, V>

pub fn reserve(&mut self, additional: usize)

pub fn shrink_to_fit(&mut self)

pub fn get_key_value<'l, Q>(&'l self, key: &Q) -> Option<(&'l K, &'l V)>
where Q: PartialEq<K> + ?Sized,

pub fn remove<Q>(&mut self, key: &Q) -> Option<V>
where Q: PartialEq<K> + ?Sized,

pub fn entry(&mut self, key: K) -> Entry<'_, K, V>
where K: PartialEq,

pub fn remove_entry<Q>(&mut self, key: &Q) -> Option<(K, V)>
where Q: PartialEq<K> + ?Sized,

pub fn retain<F>(&mut self, f: F)
where F: FnMut(&K, &mut V) -> bool,

pub fn iter(&self) -> Iter<'_, K, V>

pub fn iter_mut(&mut self) -> IterMut<'_, K, V>

pub fn sort(&mut self)
where K: Ord,

pub unsafe fn identical(&self, other: &VecMap<K, V>) -> bool
where K: PartialEq, V: PartialEq,

Much faster than self == other, but will return false if the order of the data isn’t identical.

Safety

Note that for the order of data with two VecMaps to be identical, they must either have been both sorted, or they must have undergone the insertion and removal of keys in the same order.

pub fn keys(&self) -> Keys<'_, K, V>

pub fn values(&self) -> Values<'_, K, V>