pub struct TopSortContext { /* private fields */ }Trait Implementations
Sourceimpl<'db, 'a> DataflowAnalyzer<'db, 'a> for TopSortContext
impl<'db, 'a> DataflowAnalyzer<'db, 'a> for TopSortContext
Sourcefn initial_info(
&mut self,
_block_id: BlockId,
block_end: &'a BlockEnd<'db>,
) -> Self::Info
fn initial_info( &mut self, _block_id: BlockId, block_end: &'a BlockEnd<'db>, ) -> Self::Info
Create the initial analysis state at a terminal block. Read more
Sourcefn merge(
&mut self,
_lowered: &Lowered<'db>,
_statement_location: StatementLocation,
_info1: Self::Info,
_info2: Self::Info,
) -> Self::Info
fn merge( &mut self, _lowered: &Lowered<'db>, _statement_location: StatementLocation, _info1: Self::Info, _info2: Self::Info, ) -> Self::Info
Merge/join states from multiple control flow paths.
Called at join points (match merge for backward, block entry for forward). Read more
Sourcefn visit_block_start(
&mut self,
_info: &mut Self::Info,
block_id: BlockId,
_block: &Block<'db>,
)
fn visit_block_start( &mut self, _info: &mut Self::Info, block_id: BlockId, _block: &Block<'db>, )
Called when entering a block during traversal (before transfer_block).
Sourcefn transfer_stmt(
&mut self,
_info: &mut Self::Info,
_statement_location: StatementLocation,
stmt: &'a Statement<'db>,
)
fn transfer_stmt( &mut self, _info: &mut Self::Info, _statement_location: StatementLocation, stmt: &'a Statement<'db>, )
Transfer function for a single statement. Read more
Sourcefn transfer_edge(
&mut self,
info: &Self::Info,
edge: &Edge<'db, 'a>,
) -> Self::Info
fn transfer_edge( &mut self, info: &Self::Info, edge: &Edge<'db, 'a>, ) -> Self::Info
Transfer state along a CFG edge.
Called when traversing between blocks via control flow edges. Read more
Sourcefn transfer_block(
&mut self,
info: &mut Self::Info,
block_id: BlockId,
block: &'a Block<'db>,
)
fn transfer_block( &mut self, info: &mut Self::Info, block_id: BlockId, block: &'a Block<'db>, )
Transfer function for an entire block. Read more
Sourcefn block_entry_location(
&self,
lowered: &Lowered<'db>,
block_id: BlockId,
) -> LocationId<'db>
fn block_entry_location( &self, lowered: &Lowered<'db>, block_id: BlockId, ) -> LocationId<'db>
Block entry location.
For Backward it is the merge location.
For Forward it is the block entry location, if there is a statement.
If not statement exists it will look at block end. This might recurse to next block if we
have a goto with no remappings.