Module analysis

Module analysis 

Dataflow analysis utilities for the lowering IR.

This module provides generic analysis frameworks that can be used by various optimization passes and semantic checks.

Re-exports

pub use backward::BackAnalysis;
pub use backward::DataflowBackAnalysis;
pub use core::DataflowAnalyzer;
pub use core::Direction;
pub use core::Edge;
pub use core::StatementLocation;
pub use forward::ForwardDataflowAnalysis;

Modules

backward
This module introduces the BackAnalysis utility that allows writing analyzers that go backwards in the flow of the program, on a Lowered representation.
core
Core dataflow analysis traits.
def_site
Def-site analysis for lowered IR.
dominator
Block dominator analysis for lowered IR.
equality_analysis
Equality analysis for lowered IR.
forward
Forward dataflow analysis runner.
topological_order
use_sites
Mutable use-site tracking for lowered IR variables.

Enums

DefLocation
Where a variable is defined.
UseLocation
Where a variable is used.

Traits

Analyzer
Analyzer trait to implement for each specific analysis.