pub struct EqualityAnalysis<'a, 'db> { /* private fields */ }Expand description
Variable equality analysis.
This analyzer tracks snapshot/desnap, box/unbox, struct construct, and array construct
relationships as data
flows through the program. At merge points (after match arms converge), we union-find variables
that share the same equivalence classes in both branches ((rep1, rep2) meet), rebuild
forward / reverse, and intersect relations without mapping variables across differing
branch-local equivalence roots (structure fields fall back to placeholders).
Implementations