pub struct EqualityState<'db> { /* private fields */ }Expand description
State for the equality analysis, tracking variable equivalences.
This is the Info type for the dataflow analysis. Each block gets its own
EqualityState representing what we know at that point in the program.
Uses sparse HashMaps for efficiency - only variables that have been touched by the analysis are stored.